==> flutter_custom_form_component-0.0.9.tar.gz: lib/widget/field/money/money.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_custom_form_component/widget/field/field.dart';
import 'package:flutter_custom_form_component/widget/field/mixin.dart';
import 'package:flutter_custom_form_component/widget/field/money/formatter.dart';

/// Text field supports money format.
class MoneyFieldWidget extends FieldWidget {
  late final String _decimalSeparator, _thousandSeparator;
  late final String? _hint;
  late final double? _initialValue;
  late final Function(double? value)? _onChanged;
  late final String? _symbol;

  MoneyFieldWidget(
      {String? hint,
      double? initialValue,
      bool isUsingPeriodInThousand = true,
      Function(double? value)? onChanged,
      String? symbol,
      Key? key})
      : super(key: key) {
    _hint = hint;
    _initialValue = initialValue;
    _onChanged = onChanged;
    _symbol = symbol;

    /// Using '.' for separating thousands and ',' for separating decimal. Or the opposite.
    _decimalSeparator = isUsingPeriodInThousand ? ',' : '.';
    _thousandSeparator = isUsingPeriodInThousand ? '.' : ',';
  }

  @override
  State<StatefulWidget> createState() => _State();
}

class _State extends State<MoneyFieldWidget> with FieldWidgetMixin {
  final TextEditingController _controller = TextEditingController();
  late final MoneyFormatter _formatter;

  @override
  Widget build(final BuildContext context) => container(
      textField: TextField(
          controller: _controller,
          decoration:
              InputDecoration(border: InputBorder.none, hintText: widget._hint),
          inputFormatters: [
            FilteringTextInputFormatter.allow(
                RegExp('[0-9${widget._decimalSeparator}]')),
            _formatter
          ],
          keyboardType: Platform.isAndroid
              ? const TextInputType.numberWithOptions(decimal: true)
              : TextInputType.text));

  void _controllerListener() {
    String text = _controller.text
        .replaceAll(widget._thousandSeparator, '')
        .replaceAll(widget._decimalSeparator, '');
    if (widget._symbol != null) {
      text = text.replaceFirst(widget._symbol!, '');
    }
    widget._onChanged?.call(double.tryParse(_controller.text));
  }

  @override
  void dispose() {
    _controller.removeListener(_controllerListener);
    _controller.dispose();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    _formatter = MoneyFormatter(
        decimalSeparator: widget._decimalSeparator,
        symbol: widget._symbol,
        thousandSeparator: widget._thousandSeparator);

    _controller.addListener(_controllerListener);
    if (widget._initialValue != null) {
      /// Replace common decimal separator with widget._decimalSeparator
      String initialValue = widget._initialValue!
          .toString()
          .replaceFirst('.', widget._decimalSeparator);
      final List<String> strings = initialValue.split(widget._decimalSeparator);
      if (int.tryParse(strings[1]) == 0) {
        initialValue = strings[0];
      }
      _controller.text = _formatter.format(initialValue);
      _controller.selection =
          TextSelection.collapsed(offset: _controller.text.length);
    }
  }
}

==> flutter_custom_form_component-0.0.10.tar.gz: lib/widget/field/money/money.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_custom_form_component/widget/field/field.dart';
import 'package:flutter_custom_form_component/widget/field/mixin.dart';
import 'package:flutter_custom_form_component/widget/field/money/formatter.dart';

/// Text field supports money format.
class MoneyFieldWidget extends FieldWidget {
  late final String _decimalSeparator, _thousandSeparator;
  late final String? _hint;
  late final double? _initialValue;
  late final Function(double? value)? _onChanged;
  late final String? _symbol;

  MoneyFieldWidget(
      {String? hint,
      double? initialValue,
      bool isUsingPeriodInThousand = true,
      Function(double? value)? onChanged,
      String? symbol,
      Key? key})
      : super(key: key) {
    _hint = hint;
    _initialValue = initialValue;
    _onChanged = onChanged;
    _symbol = symbol;

    /// Using '.' for separating thousands and ',' for separating decimal. Or the opposite.
    _decimalSeparator = isUsingPeriodInThousand ? ',' : '.';
    _thousandSeparator = isUsingPeriodInThousand ? '.' : ',';
  }

  @override
  State<StatefulWidget> createState() => _State();
}

class _State extends State<MoneyFieldWidget> with FieldWidgetMixin {
  final TextEditingController _controller = TextEditingController();
  late final MoneyFormatter _formatter;

  @override
  Widget build(final BuildContext context) => container(
      textField: TextField(
          controller: _controller,
          decoration:
              InputDecoration(border: InputBorder.none, hintText: widget._hint),
          inputFormatters: [
            FilteringTextInputFormatter.allow(
                RegExp('[0-9${widget._decimalSeparator}]')),
            _formatter
          ],
          keyboardType: Platform.isAndroid
              ? const TextInputType.numberWithOptions(decimal: true)
              : TextInputType.text));

  void _controllerListener() {
    String text = _controller.text
        .replaceAll(widget._thousandSeparator, '')
        .replaceAll(widget._decimalSeparator, '');
    if (widget._symbol != null) {
      text = text.replaceFirst(widget._symbol!, '');
    }
    widget._onChanged?.call(double.tryParse(text));
  }

  @override
  void dispose() {
    _controller.removeListener(_controllerListener);
    _controller.dispose();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    _formatter = MoneyFormatter(
        decimalSeparator: widget._decimalSeparator,
        symbol: widget._symbol,
        thousandSeparator: widget._thousandSeparator);

    _controller.addListener(_controllerListener);
    if (widget._initialValue != null) {
      /// Replace common decimal separator with widget._decimalSeparator
      String initialValue = widget._initialValue!
          .toString()
          .replaceFirst('.', widget._decimalSeparator);
      final List<String> strings = initialValue.split(widget._decimalSeparator);
      if (int.tryParse(strings[1]) == 0) {
        initialValue = strings[0];
      }
      _controller.text = _formatter.format(initialValue);
      _controller.selection =
          TextSelection.collapsed(offset: _controller.text.length);
    }
  }
}
